/*
 * Program        : ampis.h
 *
 * Objectives     : Finding a subset of items in order to give a maximum profit in MPIS by MPIS_Alg
 *
 * Assumptions    : Item ID in dataset file should start from zero.
 *                  I.e. if there are NUM items in the dataset, 
 *                  the item ID should be from 0 to NUM-1.
 *
 * Variations     : 
 *
 * Platform       : SunOS/Linux
 * Compiler       : gcc
 *
 * Programmer     : Raymond Chi-Wing Wong
 * Creation Date  : Oct, 2002
 * Last Update    : Jun 9, 2004
 *
 * Reference      :
 *   1. J. Han, J. Pei, and Y. Yin, 
 *      "Mining Frequent Patterns without Candidate Generation", 
 *      Proc. ACM SIGMOD 2000.
 *   2. R. C.-W. Wong, A. W.-C. Fu and K. Wang
 *      "MPIS: Maximal-Profit Item Selection with Cross-Selling Considerations"
 *      The 2003 IEEE International Conference on Data Mining (ICDM)
 *      
 */

#ifndef AMPIS_H
#define AMPIS_H

#include "readFP.h"
#include "fpt.h"

// data structure
struct trans_s		// correspond to a transaction
{
	int noOfItem;	// no. of items in a transaction
	int *item;		// item list
};

typedef struct trans_s trans;
typedef trans *transPtr;



transPtr *readData(char *filename, int noOfTrans);
int *deriveIndividualCount(transPtr *data, largeitemPtr *freqitemset, int noOfTrans, int noOfItem);
int getSupportTwo(largeitemPtr *freqitemset, int i, int j);
int **calculateEst(int *profit, int *indCount, largeitemPtr *freqitemset, int noOfItem, short **matrix);
int *calculateEst2(int itemI, int *profit, int *indCount, largeitemPtr *freqitemset, int noOfItem, short **matrix);
int *sort(int *element, int noOfElt);
double calculateBenefit(transPtr *data, int noOfTrans, short **matrx, int *elt, int noOfElt, int itemI, int profit);
double calculateBenefit2(transPtr *data, int noOfTrans, short **matrix, int *elt, int noOfElt, int *profit);
double calculateBenefit3(transPtr *data, int noOfTrans, short **matrix, int *elt, int noOfElt, int *profit);
double calculateBenefitFP(transPtr *data, int noOfTrans, short **matrix, int *elt, int noOfElt, int *profit, double *revNo, int *chooseFlag);
double calculateBenefitFP2(transPtr *data, int noOfTrans, short **matrix, int *elt, int noOfElt, int *profit, double *revNo, int *chooseFlag, int itemSpecial);

double calculateBenefitFP_diff(transPtr *data, int noOfTrans, short **matrix, int *elt, int noOfElt, int *profit, double *revNo, int *chooseFlag, int itemAdd, int itemRemove);

short **transform2Matrix(largeitemPtr *freqitemset, int noOfElt);

double getConf(transPtr *data, int noOfTrans, short **matrix, int *d, int noOfElt, int itemI);

void sortFreqItemSet(largeitemPtr *freqitemset);

short *getBestJItem(int *element, int noOfElt, int boundJ);
short *getBestJItem2(int *element, int noOfElt, int boundJ, int *noOfJ);

int getMatrix(int itemI, int itemJ);

short *getWorstJItem2(int *element, int noOfElt, int boundJ, int *noOfJ);
void transform2Select(int *s, short *S, int noOfJ, short *sortEstIndex2, int itemI);

#endif
