/*
 * Program        : fpt_mpis.h
 *
 * Objectives     : to implement the functions used in FP-MPIS-tree
 *
 * Assumptions    : Item ID in dataset file should start from zero.
 *                  I.e. if there are NUM items in the dataset, 
 *                  the item ID should be from 0 to NUM-1.
 *
 * Variations     : 
 *
 * Platform       : SunOS/Linux
 * Compiler       : gcc
 *
 * Programmer     : Raymond Chi-Wing Wong
 * Creation Date  : Oct, 2002
 * Last Update    : Jun 9, 2004
 *
 * Reference      :
 *   1. J. Han, J. Pei, and Y. Yin, 
 *      "Mining Frequent Patterns without Candidate Generation", 
 *      Proc. ACM SIGMOD 2000.
 *   2. R. C.-W. Wong, A. W.-C. Fu and K. Wang
 *      "MPIS: Maximal-Profit Item Selection with Cross-Selling Considerations"
 *      The 2003 IEEE International Conference on Data Mining (ICDM)
 *      
 */

#ifndef FPT_M_H
#define FPT_M_H

#include "ampis.h"
#include "fpt.h"

extern int noOfTrans;
extern int noOfItem;

FPTreeNode rootSet;		/* Initial FP-tree */
FPTreeNode *headerTableLinkSet;	/* Corresponding header table */

FPTreeNode rootSet2;		/* Initial FP-tree */
FPTreeNode *headerTableLinkSet2;	/* Corresponding header table */



double buildTreeSet(transPtr *data, short *fpMap, int *isChoose, int *profit, double *revNo, int *chooseFlag);
void free_fpSet();
void free_fpSet2();
void getBenefitFP(double *returnValue, FPTreeNode node, int *isChoose, int *profit, double *revNo);

double buildTreeSet2(transPtr *data, short *fpMap, int *isChoose, int *profit, double *revNo, int *chooseFlag, int itemSpecial);
void getBenefitFP2(double *returnValue, double *returnValue2, FPTreeNode node, int *isChoose, int *profit, double *revNo, int itemSpecial);


double buildTreeSet_diff(transPtr *data, short *fpMap, short *fpMap2, int *isChoose, int *profit, double *revNo, int *chooseFlag, int itemAdd, int itemRemove);

#endif



